.. snowdrift documentation master file, created by
   sphinx-quickstart on Wed Feb 11 13:57:37 2026.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

snowdrift documentation
=======================

TODO: Add project description here.

Contents
--------

.. toctree::

   index <self>
   usage

API Reference
-------------

.. autosummary::
   :toctree: generated/
   :recursive:
   :caption: API reference

   snowdrift.breeze
   snowdrift.breeze_cpp
   snowdrift.cli
   snowdrift.code_writer
   snowdrift.common
   snowdrift.config
   snowdrift.core


.. code-block:: python

   x = 2
   assert x == 2
